<?php

namespace Drupal\resourcespace_integration\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure ResourceSpace settings for this module.
 */
class ResourceSpaceSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['resourcespace_integration.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'resourcespace_integration_settings_form';
  }

  /**
   * Build the settings form.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('resourcespace_integration.settings');

    $form['resourcespace_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('ResourceSpace API URL'),
      '#default_value' => $config->get('resourcespace_url'),
      '#description' => $this->t('Enter the base URL for the ResourceSpace API.'),
      '#required' => TRUE,
    ];

    $form['resourcespace_username'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Username'),
      '#default_value' => $config->get('resourcespace_username'),
      '#description' => $this->t('Enter the username for ResourceSpace.'),
      '#required' => TRUE,
    ];

    $form['resourcespace_api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key'),
      '#default_value' => $config->get('resourcespace_api_key'),
      '#description' => $this->t('Enter the api key for ResourceSpace.'),
      '#required' => TRUE,
    ];

    $form['resourcespace_enable_media_filter'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Media Filter'),
      '#default_value' => $config->get('resourcespace_enable_media_filter') ?? false,
      '#description' => $this->t('Check this box to enable filter through ResourceSpace while media filter action.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * Submit handler for the settings form.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('resourcespace_integration.settings')
      ->set('resourcespace_url', $form_state->getValue('resourcespace_url'))
      ->set('resourcespace_username', $form_state->getValue('resourcespace_username'))
      ->set('resourcespace_api_key', $form_state->getValue('resourcespace_api_key'))
      ->set('resourcespace_enable_media_filter', $form_state->getValue('resourcespace_enable_media_filter'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
